@@ -7,12 +7,13 @@ from peek_plugin_graphdb._private.PluginNames import graphDbTuplePrefix
 
 @addTupleType
 class ItemKeyTuple(Tuple):
-    """ Item Key Tuple
+    """Item Key Tuple
 
     This tuple provides the segment keys of a vertex or edge within the GraphDB model.
 
     """
-    __tupleType__ = graphDbTuplePrefix + 'ItemKeyTuple'
+
+    __tupleType__ = graphDbTuplePrefix + "ItemKeyTuple"
 
     #:  The unique key of this itemKeyIndex
     key: str = TupleField()
@@ -31,15 +32,14 @@ class ItemKeyTuple(Tuple):
     #:  The key of the segment where it's stored
     segmentKeys: str = TupleField()
 
-    def unpackJson(self, key: str, packedJson: str,
-                   modelSetKey: str) -> 'ItemKeyTuple':
+    def unpackJson(self, key: str, packedJson: str, modelSetKey: str) -> "ItemKeyTuple":
         # Reconstruct the data
         objectProps: {} = json.loads(packedJson)
 
         # Unpack the custom data here
         self.itemKey = key
         self.modelSetKey = modelSetKey
-        self.itemType = objectProps.get('itemType')
-        self.segmentKeys = objectProps.get('encodedChunkKeys')
+        self.itemType = objectProps.get("itemType")
+        self.segmentKeys = objectProps.get("encodedChunkKeys")
 
         return self
