@@ -1,3 +1,5 @@
+import { Observable, Subject } from "rxjs";
+import { filter, first, takeUntil } from "rxjs/operators";
 import { Injectable } from "@angular/core";
 import {
     extend,
@@ -10,7 +12,6 @@ import {
     TupleStorageFactoryService,
     VortexService,
     VortexStatusService,
-    TupleStorageBatchSaveArguments,
 } from "@synerty/vortexjs";
 
 import {
@@ -18,17 +19,17 @@ import {
     graphDbFilt,
     graphDbTuplePrefix,
 } from "../PluginNames";
-
-import { Observable, Subject } from "rxjs";
 import { ItemKeyIndexEncodedChunkTuple } from "./ItemKeyIndexEncodedChunkTuple";
 import { ItemKeyIndexUpdateDateTuple } from "./ItemKeyIndexUpdateDateTuple";
 import { ItemKeyTuple } from "./ItemKeyTuple";
 import { ItemKeyIndexLoaderStatusTuple } from "./ItemKeyIndexLoaderStatusTuple";
-
-import { OfflineConfigTuple } from "../tuples/OfflineConfigTuple";
 import { GraphDbModelSetTuple } from "../../GraphDbModelSetTuple";
 import { GraphDbTupleService } from "../GraphDbTupleService";
 import { GraphDbPackedItemKeyTuple } from "./GraphDbPackedItemKeyTuple";
+import {
+    DeviceOfflineCacheControllerService,
+    OfflineCacheStatusTuple,
+} from "@peek/peek_core_device";
 
 // ----------------------------------------------------------------------------
 
@@ -129,32 +130,15 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
     private modelSetByIds: { [id: number]: GraphDbModelSetTuple } = {};
     private _hasModelSetLoaded = false;
 
-    private offlineConfig: OfflineConfigTuple = new OfflineConfigTuple();
-
     constructor(
         private vortexService: VortexService,
         private vortexStatusService: VortexStatusService,
         storageFactory: TupleStorageFactoryService,
-        private tupleService: GraphDbTupleService
+        private tupleService: GraphDbTupleService,
+        private deviceCacheControllerService: DeviceOfflineCacheControllerService
     ) {
         super();
 
-        this.tupleService.offlineObserver
-            .subscribeToTupleSelector(
-                new TupleSelector(OfflineConfigTuple.tupleName, {}),
-                false,
-                false,
-                true
-            )
-            .takeUntil(this.onDestroyEvent)
-            .filter((v) => v.length != 0)
-            .subscribe((tuples: OfflineConfigTuple[]) => {
-                this.offlineConfig = tuples[0];
-                if (this.offlineConfig.cacheChunksForOffline)
-                    this.initialLoad();
-                this._notifyStatus();
-            });
-
         this.storage = new TupleOfflineStorageService(
             storageFactory,
             new TupleOfflineStorageNameService(graphDbCacheStorageName)
@@ -163,10 +147,13 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
         this.setupVortexSubscriptions();
         this._notifyStatus();
 
-        // Check for updates every so often
-        Observable.interval(this.OFFLINE_CHECK_PERIOD_MS)
-            .takeUntil(this.onDestroyEvent)
-            .subscribe(() => this.askServerForUpdates());
+        this.deviceCacheControllerService.triggerCachingObservable
+            .pipe(takeUntil(this.onDestroyEvent))
+            .pipe(filter((v) => v))
+            .subscribe(() => {
+                this.initialLoad();
+                this._notifyStatus();
+            });
     }
 
     isReady(): boolean {
@@ -217,7 +204,7 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
 
     private _notifyStatus(): void {
         this._status.cacheForOfflineEnabled =
-            this.offlineConfig.cacheChunksForOffline;
+            this.deviceCacheControllerService.cachingEnabled;
         this._status.initialLoadComplete = this.index.initialLoadComplete;
 
         this._status.loadProgress = Object.keys(
@@ -229,6 +216,15 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
             ).length;
 
         this._statusSubject.next(this._status);
+
+        const status = new OfflineCacheStatusTuple();
+        status.pluginName = "peek_plugin_graphdb";
+        status.indexName = "Key Index";
+        status.loadingQueueCount = this._status.loadProgress;
+        status.totalLoadedCount = this._status.loadTotal;
+        status.lastCheckDate = new Date();
+        status.initialFullLoadComplete = this._status.initialLoadComplete;
+        this.deviceCacheControllerService.updateCachingStatus(status);
     }
 
     /** Initial load
@@ -263,21 +259,21 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
                 this,
                 clientItemKeyIndexWatchUpdateFromDeviceFilt
             )
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
                 this.processItemKeyIndexsFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
         this.vortexStatusService.isOnline
-            .filter((isOnline) => isOnline == true)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(filter((isOnline) => isOnline == true))
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(() => this.askServerForUpdates());
     }
 
     private areWeTalkingToTheServer(): boolean {
         return (
-            this.offlineConfig.cacheChunksForOffline &&
+            this.deviceCacheControllerService.cachingEnabled &&
             this.vortexStatusService.snapshot.isOnline
         );
     }
@@ -339,7 +335,7 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
 
         for (let key of keysNeedingUpdate) {
             indexChunk.updateDateByChunkKey[key] =
-                this.index.updateDateByChunkKey[key];
+                this.index.updateDateByChunkKey[key] || "";
             count++;
 
             if (count == this.UPDATE_CHUNK_FETCH_SIZE) {
@@ -430,19 +426,26 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
      * Stores the index bucket in the local db.
      */
     private storeItemKeyIndexChunkTuples(
-        tuplesToSave: ItemKeyIndexEncodedChunkTuple[]
+        encodedItemKeyIndexChunkTuples: ItemKeyIndexEncodedChunkTuple[]
     ): Promise<void> {
-        const Selector = ItemKeyIndexChunkTupleSelector;
-        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        let retPromise: any;
+        retPromise = this.storage.transaction(true).then((tx) => {
+            let promises = [];
 
-        for (const tuple of tuplesToSave) {
-            batchStore.push({
-                tupleSelector: new Selector(tuple.chunkKey),
-                vortexMsg: tuple.encodedData,
-            });
-        }
+            for (let encodedItemKeyIndexChunkTuple of encodedItemKeyIndexChunkTuples) {
+                promises.push(
+                    tx.saveTuplesEncoded(
+                        new ItemKeyIndexChunkTupleSelector(
+                            encodedItemKeyIndexChunkTuple.chunkKey
+                        ),
+                        encodedItemKeyIndexChunkTuple.encodedData
+                    )
+                );
+            }
 
-        return this.storage.batchSaveTuplesEncoded(batchStore);
+            return Promise.all(promises).then(() => tx.close());
+        });
+        return retPromise;
     }
 
     /** Get Segment Keys
@@ -464,7 +467,7 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
 
         // If there is no offline support, or we're online
         if (
-            !this.offlineConfig.cacheChunksForOffline ||
+            !this.deviceCacheControllerService.cachingEnabled ||
             this.vortexStatusService.snapshot.isOnline
         ) {
             let ts = new TupleSelector(GraphDbPackedItemKeyTuple.tupleName, {
@@ -476,8 +479,8 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
                 .isOnline
                 ? Promise.resolve()
                 : this.vortexStatusService.isOnline
-                      .filter((online) => online)
-                      .first()
+                      .pipe(filter((online) => online))
+                      .pipe(first())
                       .toPromise();
 
             return isOnlinePromise
@@ -504,7 +507,7 @@ export class ItemKeyIndexLoaderService extends NgLifeCycleEvents {
         if (this.isReady()) return this.getItemKeysWhenReady(modelSetKey, keys);
 
         return this.isReadyObservable()
-            .first()
+            .pipe(first())
             .toPromise()
             .then(() => this.getItemKeysWhenReady(modelSetKey, keys));
     }
